..
    Copyright (C) 2022 CERN.

    Invenio-Users-Resources is free software; you can redistribute it
    and/or modify it under the terms of the MIT License; see LICENSE file for
    more details.


API Docs
========

.. automodule:: invenio_users_resources.ext
   :members:

Views
-----

.. automodule:: invenio_users_resources.views
   :members:
